==> o365-3.0.x-dev.tar.gz: o365/modules/o365_onedrive/src/Plugin/Block/SharedFilesBlock.php <==
<?php

namespace Drupal\o365_onedrive\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\o365\Block\O365UncachedBlockBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface;

/**
 * Provides a 'Shared Files' block.
 *
 * @Block(
 *   id = "o365_shared_files",
 *   admin_label = @Translation("Shared Files"),
 *   category = @Translation("Office 365")
 * )
 */
class SharedFilesBlock extends O365UncachedBlockBase implements ContainerFactoryPluginInterface {

  /**
   * Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface definition.
   *
   * @var \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface
   */
  protected $getFilesAndFoldersService;

  /**
   * Constructs a new SharedFilesBlock object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface $o365_onedrive_get_files
   *   The GetFilesAndFoldersServiceInterface definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, GetFilesAndFoldersServiceInterface $o365_onedrive_get_files) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->getFilesAndFoldersService = $o365_onedrive_get_files;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('o365_onedrive.get_files')
    );
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   * @throws \Microsoft\Graph\Exception\GraphException
   */
  public function build() {
    $blockData = $this->getFilesAndFoldersService->listSharedFilesAndFolders();

    if (!empty($blockData)) {
      return $blockData;
    }

    $config = $this->getConfiguration();

    if ($config['show_shared_files_block']) {
      return [
        '#theme' => 'o365_onedrive_results',
        '#results' => $config['show_shared_files_block'],
      ];
    }

    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['show_shared_files_block'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show shared files when there is no data'),
      '#default_value' => ($config['show_shared_files_block']) ?? FALSE,
    ];

    $form['shared_files_block_text'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Shared files block text'),
      '#description' => $this->t('Enter the text you would like to show'),
      '#placeholder' => $this->t('Enter the text you would like to show'),
      '#default_value' => $config['shared_files_block_text'] ?? $this->t('No shared files found.'),
      '#states' => [
        'visible' => [
          ':input[name="settings[show_shared_files_block]"]' => [
            'checked' => TRUE,
          ],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['show_shared_files_block'] = $values['show_shared_files_block'];
    $this->configuration['shared_files_block_text'] = $values['shared_files_block_text'];
  }

}

==> o365-5.0.x-dev.tar.gz: o365/modules/o365_onedrive/src/Plugin/Block/SharedFilesBlock.php <==
<?php

namespace Drupal\o365_onedrive\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\o365\Block\O365UncachedBlockBase;
use Drupal\o365\GraphService;
use Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Shared Files' block.
 *
 * @Block(
 *   id = "o365_shared_files",
 *   admin_label = @Translation("Shared Files"),
 *   category = @Translation("Microsoft 365")
 * )
 */
class SharedFilesBlock extends O365UncachedBlockBase implements ContainerFactoryPluginInterface {

  /**
   * Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface definition.
   *
   * @var \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface
   */
  protected $getFilesAndFoldersService;

  /**
   * Constructs a new SharedFilesBlock object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\o365\GraphService $graphService
   *   The o365 Graph service.
   * @param \Drupal\o365_onedrive\GetFilesAndFoldersServiceInterface $getFilesAndFoldersService
   *   The GetFilesAndFoldersServiceInterface definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, GraphService $graphService, GetFilesAndFoldersServiceInterface $getFilesAndFoldersService) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $graphService);
    $this->getFilesAndFoldersService = $getFilesAndFoldersService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('o365.graph'),
      $container->get('o365_onedrive.get_files')
    );
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   * @throws \Microsoft\Graph\Exception\GraphException
   */
  public function build() {
    $blockData = $this->getFilesAndFoldersService->listSharedFilesAndFolders();

    if (!empty($blockData)) {
      return $blockData;
    }

    $config = $this->getConfiguration();

    if ($config['show_shared_files_block']) {
      return [
        '#theme' => 'o365_onedrive_results',
        '#results' => $config['show_shared_files_block'],
      ];
    }

    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['show_shared_files_block'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show shared files when there is no data'),
      '#default_value' => ($config['show_shared_files_block']) ?? FALSE,
    ];

    $form['shared_files_block_text'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Shared files block text'),
      '#description' => $this->t('Enter the text you would like to show'),
      '#placeholder' => $this->t('Enter the text you would like to show'),
      '#default_value' => $config['shared_files_block_text'] ?? $this->t('No shared files found.'),
      '#states' => [
        'visible' => [
          ':input[name="settings[show_shared_files_block]"]' => [
            'checked' => TRUE,
          ],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['show_shared_files_block'] = $values['show_shared_files_block'];
    $this->configuration['shared_files_block_text'] = $values['shared_files_block_text'];
  }

}
